@@ -8,16 +8,22 @@
  */
 
 package org.gnu.gnome;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 /**
  *
  */
 public class CanvasShape extends CanvasItem {
+
+	protected CanvasShape(CanvasGroup group, int type) {
+		super(group, type);
+	}
+	
 	/**
 	 * Constructs an instance of CanvasShape from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasShape(int handle) {
+	CanvasShape(Handle handle) {
 		super(handle);
 	}
 
@@ -28,13 +34,9 @@ public class CanvasShape extends CanvasItem {
 		return new Type(gnome_canvas_shape_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_canvas_shape_get_type();
-	native static final protected void gnome_canvas_shape_set_path_def(int shape, int def);
-	native static final protected int gnome_canvas_shape_get_path_def(int shape);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected void gnome_canvas_shape_set_path_def(Handle shape, Handle def);
+	native static final protected Handle gnome_canvas_shape_get_path_def(Handle shape);
+
 }
