@@ -13,6 +13,7 @@ import java.util.Vector;
 
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.IconEntryEvent;
 import org.gnu.gnome.event.IconEntryListener;
@@ -39,7 +40,7 @@ public class IconEntry extends VBox {
 	/**
 	 * Construct a new IconEntry from a handle to a native resource.
 	 */
-	public IconEntry(int handle) {
+	public IconEntry(Handle handle) {
 	    super(handle);
 	}
 	
@@ -177,19 +178,15 @@ public class IconEntry extends VBox {
 	}
 
 	
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_icon_entry_get_type();
-	native static final protected int gnome_icon_entry_new(String historyId, String browserDialogTitle);
-	native static final protected void gnome_icon_entry_set_pixmap_subdir(int ientry, String subdir);
-	native static final protected String gnome_icon_entry_get_filename(int ientry);
-	native static final protected boolean gnome_icon_entry_set_filename(int ientry, String filename);
-	native static final protected void gnome_icon_entry_set_browse_dialog_title(int ientry, String browseDialogTitle);
-	native static final protected void gnome_icon_entry_set_history_id(int ientry, String historyId);
-	native static final protected int gnome_icon_entry_pick_dialog(int ientry);
-	native static final protected void gnome_icon_entry_set_max_saved(int ientry, int max);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_icon_entry_new(String historyId, String browserDialogTitle);
+	native static final protected void gnome_icon_entry_set_pixmap_subdir(Handle ientry, String subdir);
+	native static final protected String gnome_icon_entry_get_filename(Handle ientry);
+	native static final protected boolean gnome_icon_entry_set_filename(Handle ientry, String filename);
+	native static final protected void gnome_icon_entry_set_browse_dialog_title(Handle ientry, String browseDialogTitle);
+	native static final protected void gnome_icon_entry_set_history_id(Handle ientry, String historyId);
+	native static final protected Handle gnome_icon_entry_pick_dialog(Handle ientry);
+	native static final protected void gnome_icon_entry_set_max_saved(Handle ientry, int max);
+
 }
